# Changelog

## [1.0.1](https://github.com/h2oai/cloud-discovery-py/compare/v1.0.0...v1.0.1) (2023-05-12)


### Documentation

* 📝 document environment version format ([#29](https://github.com/h2oai/cloud-discovery-py/issues/29)) ([1bf6f4a](https://github.com/h2oai/cloud-discovery-py/commit/1bf6f4a2a1faefce3e5141130cd05c7bdfaf48bd))
* 📝 use Sphinx `#:` comments to document model fields ([#51](https://github.com/h2oai/cloud-discovery-py/issues/51)) ([ff3a4f8](https://github.com/h2oai/cloud-discovery-py/commit/ff3a4f8f646eb304f741dae83ca260460d0f41be))
